{ open Controlparseridea }

let digit = ['0'-'9']
let line = [^ '\n'] *
let num = digit +
let ident = ['a' - 'z' 'A' - 'Z' '-' '0' - '9' '_' '.'] +
let category = ("godi" | "apps" | "conf")

rule spec = parse
    | "Package: "       { PACKAGE (line lexbuf) }
    | "Version: "       { VERSION (line lexbuf) }
    | "Revision: "      { REVISION (num lexbuf) }
    | "Category: "      { CATEGORY (category lexbuf) }
    | "Depends: "       { DEPENDS }
    | "Build-Depends: " { BUILDDEPENDS }
    | "Sources: "       { SOURCES (line lexbuf) }
    | "Homepage: "      { HOMEPAGE (line lexbuf) }
    | "Maintainer: "    { MAINTAINER (line lexbuf) }
    | "Description: "   { let short = line lexbuf in
                          let long = para lexbuf in
                          DESCRIPTION (short, long) }
    | "Options: "       { OPTIONS }
    | "Docfiles: "      { DOCFILES }
    | '('               { LPAREN }
    | ')'               { RPAREN }
    | ','               { COMMA }
    | '='               { EQ }
    | ">="              { GE }
    | '\n'              { NEWLINE }
    | ' '               { SPACE }
    | ident             { IDENT (Lexing.lexeme lexbuf) }
    | eof               { EOF }

and line = parse
    | line              { Lexing.lexeme lexbuf }

and num = parse
    | num               { int_of_string (Lexing.lexeme lexbuf) }

and category = parse
    | category          { Lexing.lexeme lexbuf }

and para = parse
    | (line '\n') * ".\n" { Lexing.lexeme lexbuf }

{ (* the trailer *) }
